Read-only operator projection. No response channels or permission grants cross this boundary.
Read-only operator projection. No response channels or permission grants cross this boundary.
(open config changed!)Create observation ports. Sources are watchable atoms; production resolves already-loaded host state. Watch callbacks only request a refresh. close removes every watch; observe! accepts bounded activity.
Create observation ports. Sources are watchable atoms; production resolves already-loaded host state. Watch callbacks only request a refresh. close removes every watch; observe! accepts bounded activity.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |